@@ -65,7 +65,7 @@ class ImageWithSizeBlock(ImageBlock):
     size = SizeChoiceBlock(required=False)
 
     class Meta:
-        template = '%s/common/image.html' % constants.BLOCK_TEMPLATES_PATH
+        template = '%s/common/picture_sizer.html' % constants.BLOCK_TEMPLATES_PATH
         label = "Image"
 
 
